/*
 * Authors:             Marco Dinarelli & Valentina Masi
 * Date last modified:  7/10/04
 *
 */

#ifndef TABLEENTRY_H  // if not used, compiler reports error over every type
#define TABLEENTRY_H  // declared in TableEntry.h because this file is
                      // included in any application over Stream System layer

#include "MsgNet.h"   // per la dichiarazione di channel_t
#include "SSTypes.h"  // per la dichiarazione di stream_buffer

#define TABLE_SIZE 4 
#define MAX_SRC 4

#define MAX_READS 4   //Ignored...

// remote stream table - source side 
typedef struct SRSDT_Entry {
	channel_t channel_id;
	uint8_t symbolic_name;   // must be greater than zero; if equal to zero, entry is empty
	uint8_t buffer_size;     // nelle altre tabelle è contenuto in stream_buffer
} SRSDT_Entry;


// remote stream table - destination side
typedef struct DRSDT_Entry {
	uint8_t symbolic_name;   // must be greater than zero; if equal to zero, entry is empty
	channel_t channel_id[MAX_SRC]; 
	uint32_t stream_rate[MAX_SRC];
	uint8_t src_validity;    // if i-th bit is 1, channel_id[i], stream_rate[i] and i-th bit of reliability are meaningful
	uint8_t reliability;     // if j-th bit is 1, j-th source has asked for reliability
	uint8_t src_counter;     // number of souces of remote stream
  stream_buffer sb;
} DRSDT_Entry;

// sensor stream table
typedef struct SSDT_Entry{
	uint8_t sensor_tid;      // if zero, entry is free
	uint32_t stream_rate;
	uint8_t sampling_type;
  stream_buffer sb;
  tos_time_t t;            // proxON...
} SSDT_Entry;

typedef struct LSDT_Entry {
	uint8_t validity;        // entry is valid if >0
  stream_buffer sb;        // stream buffer
} LSDT_Entry;

// identifiers for the different stream descriptor tables
// by now only source and destination remote stream descriptor tables are defined
// in the future it will be defined also IDs for local and sensor stream descriptor tables
enum TABLE_IDS {
	SRSDT_ID = 0,
	DRSDT_ID = 1,
	LSDT_ID = 2,
	SSDT_ID = 3,
	PSDT_ID = 4
};

// write & read return values 
enum {
	INVALID_DESCRIPTOR = -1,
	STREAM_NOT_OPEN = -2,
	SEND_FAIL = -3,
	ILLEGAL_OPERATION = -4
};

// sensor_tid
enum {
	LIGHT = 1,
	TEMPERATURE = 2,
	VOICE = 3,
	MAGNETISMX = 4,
	MAGNETISMY = 5,
	ACCELERATIONX = 6,
	ACCELERATIONY = 7
};

// sampling_type
enum {
	PERIODIC = 1,
	ON_DEMAND = 2,
};

#endif
